class oci::swiftproxy(
  $machine_hostname          = undef,
  $machine_ip                = undef,
  $first_master              = undef,
  $first_master_ip           = undef,
  $vip_hostname              = undef,
  $vip_ipaddr                = undef,
  $vip_netmask               = undef,
  $network_ipaddr            = undef,
  $network_cidr              = undef,
  $all_masters               = undef,
  $all_masters_ip            = undef,
  $all_swiftstore_ip         = undef,
  $all_swiftstore            = undef,
  $pass_swift_authtoken      = undef,
  $pass_swift_hashpathsuffix = undef,
  $pass_swift_hashpathprefix = undef,
  $use_ssl                   = true,
){

  if $use_ssl {
    $proto = 'https'
    $api_port = 443
  } else {
    $proto = 'http'
    $api_port = 80
  }

  $base_url = "${proto}://${vip_hostname}"
  $keystone_auth_uri  = "${base_url}/identity"
  $keystone_admin_uri = "${base_url}/identity-admin"
  $memcached_servers  = ["127.0.0.1:11211"]

  package { 'rsyslog':
    ensure => present,
  }
  service { 'rsyslog':
    ensure  => running,
    enable  => true,
    require => Package['rsyslog'],
  }

  file { '/var/log/swift':
    ensure => directory,
    mode   => '0750',
  }

  file { '/etc/rsyslog.d/10-swift.conf':
    ensure  => present,
    source  => "puppet:///modules/${module_name}/rsyslog-swift.conf",
    require => [Package['rsyslog'], File['/var/log/swift']],
    notify  => Service['rsyslog'],
  }

  File<| title == '/var/log/swift' |> {
    owner => 'swift',
    group => 'adm'
  }

  # Get memcached
  class { '::memcached':
    listen_ip => $::fqdn,
    udp_port  => 0,
  }

  class { '::swift':
    swift_hash_path_suffix => $pass_swift_hashpathsuffix,
    swift_hash_path_prefix => $pass_swift_hashpathprefix,
  }

  class { '::swift::proxy':
    proxy_local_net_ip => $machine_ip,
    port               => '8080',
    account_autocreate => true,
# Note: We will re-add 'cache' when we have memcache working.
#    pipeline           => [ 'catch_errors', 'healthcheck', 'cache', 'ratelimit', 'authtoken', 'proxy-server' ],
    pipeline           => [ 'catch_errors', 'healthcheck', 'cache', 'ratelimit', 'authtoken', 'proxy-server' ],
    node_timeout       => 30,
  }
  include ::swift::proxy::catch_errors
  include ::swift::proxy::healthcheck
  class { '::swift::proxy::cache':
    memcache_servers => ["${::fqdn}:11211"],
  }
  include ::swift::proxy::tempauth
  include ::swift::keystone::auth
  include ::swift::proxy::ratelimit

  class { '::swift::proxy::authtoken':
    auth_uri                => "${keystone_auth_uri}/v3",
    auth_url                => $keystone_admin_uri,
    password                => $pass_swift_authtoken,
    delay_auth_decision     => 'True',
    cache                   => 'swift.cache',
    include_service_catalog => 'False',
  }

  swift_proxy_config {
    'filter:authtoken/cafile': value => '/etc/ssl/certs/oci-pki-oci-ca-chain.pem';
  }

#  $swift_components = ['account', 'container', 'object']
#  swift::storage::filter::recon { $swift_components : }
#  swift::storage::filter::healthcheck { $swift_components : }
}
